# bqscales

Grammar of Graphics in Python for bqplot and other Jupyter widgets libraries

## Installation

You can install using ``pip``:

```bash
pip install bqscales
```

Or using ``conda``/``mamba``:

```bash
mamba install -c conda-forge bqscales
```

## Development

See our [contributing guidelines](CONTRIBUTING.md) to know how to contribute and set up a development environment.

## License

This software is licensed under the Apache 2.0 license. See the [LICENSE](LICENSE) file for details.
